summaryrefslogtreecommitdiffstats
path: root/tools/safely-roll-blink.py
diff options
context:
space:
mode:
authordanakj@chromium.org <danakj@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-09 18:01:32 +0000
committerdanakj@chromium.org <danakj@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-09 18:01:32 +0000
commitb69cc1d03f372fba1882ab52916ff4aec02d2bbe (patch)
tree5a3435f786f3de6a30a0c8e6ff7cb83ecd6a2863 /tools/safely-roll-blink.py
parentcf154381f30b8ae7b1f255e00443cbc4888ba0fe (diff)
downloadchromium_src-b69cc1d03f372fba1882ab52916ff4aec02d2bbe.zip
chromium_src-b69cc1d03f372fba1882ab52916ff4aec02d2bbe.tar.gz
chromium_src-b69cc1d03f372fba1882ab52916ff4aec02d2bbe.tar.bz2
Refer to blink in the safely-roll-blink script.
Still some old references to webkit that should be changed (unlike the references to "webkit_revision" which is actually what the DEPS files says). NOTRY=true Review URL: https://chromiumcodereview.appspot.com/14752019 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@199243 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'tools/safely-roll-blink.py')
-rwxr-xr-xtools/safely-roll-blink.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/safely-roll-blink.py b/tools/safely-roll-blink.py
index cc01c4e..581aecd 100755
--- a/tools/safely-roll-blink.py
+++ b/tools/safely-roll-blink.py
@@ -3,7 +3,7 @@
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
"""Generate a CL to roll webkit to the specified revision number and post
it to Rietveld so that the CL will land automatically if it passes the
commit-queue's checks.
"""
@@ -44,7 +44,7 @@ def process_deps(path, new_rev, is_dry_run):
def main():
tool_dir = os.path.dirname(os.path.abspath(__file__))
- parser = optparse.OptionParser(usage='%prog [options] <new webkit rev>')
+ parser = optparse.OptionParser(usage='%prog [options] <new blink rev>')
parser.add_option('-v', '--verbose', action='count', default=0)
parser.add_option('--dry-run', action='store_true')
parser.add_option('--commit', action='store_true', default=True,
@@ -3,7 +3,7 @@
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
-"""Generate a CL to roll webkit to the specified revision number and post
+"""Generate a CL to roll Blink to the specified revision number and post
it to Rietveld so that the CL will land automatically if it passes the
commit-queue's checks.